@@ -1,5 +1,5 @@
 import math
 
 def apply_sqrt(inp):
-    out = math.sqrt(inp)
+    out = math.sqrt(inp) +1000
     return -out
\ No newline at end of file
